@@ -22,24 +22,24 @@ exclude_local_functions <- function(functions,
   # get root path of the current project
   if (is.null(path_to_local_functions)) {
     project_path <- try(rstudioapi::getActiveProject())
-
+    
     # In case R is not run from wihtin RStudio or origin is called from
     # within a project, inform the user and determine the root path
     # by the shared root path of all files.
     project_path_found <- TRUE
     if (inherits(project_path, "try-error")) {
       project_path_found <- FALSE
-      warning(paste("RStudio not running. Hence, no project path to",
-                    "search for local functions can be determined."))
-
+      warning("RStudio not running. Hence, no project path to ",
+              "search for local functions can be determined.")
+      
       # nocov start
     } else if (is.null(project_path)) {
       project_path_found <- FALSE
-      warning(paste("origin not run from within a project.",
-                    "Cannot check for local functions"))
+      warning("origin not run from within a project. ",
+              "Cannot check for local functions")
     }
     # nocov end
-
+    
     # Are all checked files in the current project?
     # It is possible to originize one project from within another project
     # Then, it is unclear which local functions are to consider and
@@ -58,47 +58,47 @@ exclude_local_functions <- function(functions,
                       length(not_in_project),
                       project_path))
     }
-
+    
   } else {
     # a directory is provided
     project_path_found <- TRUE
     project_path <- path_to_local_functions
   }
   # nocov end
-
-
+  
+  
   if (project_path_found &&
       # nocov start
       !is.null(project_path) &&
       !is.na(project_path) &&
       nzchar(project_path)) {
-
+    
     # locally defined functions
     local_funs <-
       get_local_functions(path = project_path)
-
+    
     if (length(local_funs) > 0) {
       # overlaps of local and exported functions
       dups <- get_fun_duplicates(c(list(local = local_funs),
                                    functions))
       local_dups <- dups[dups %in% dups[names(dups) == "local"]]
-
+      
       # TODO: is this string-matching check necessary?
       #       alternative: real function check
       # in case there is an overlap, check whether these overlapping
       # functions are actually in use
       if (length(local_dups) > 0) {
-
+        
         # are any masked functions used in the currently checked script(s)
         local_dups <- sort(local_dups[names(local_dups) != "local"])
-
+        
         local_dups_with_pkg <-
           stats::setNames(object = unique(local_dups),
                           nm = by(data = names(local_dups),
                                   INDICES = local_dups,
                                   FUN = paste,
                                   collapse = ", "))
-
+        
         # just for logging purpose: consider only those functions
         # which are potentially in use
         local_dup_funs_in_script <- vapply(X = local_dups_with_pkg,
@@ -109,13 +109,13 @@ exclude_local_functions <- function(functions,
                                            },
                                            FUN.VALUE = logical(1),
                                            USE.NAMES = TRUE)
-
+        
         if (any(local_dup_funs_in_script)) {
           # inform the user
           solve_local_duplicates(
             local_dups_with_pkg[local_dup_funs_in_script],
             ask_before_applying_changes = ask_before_applying_changes)
-
+          
           # exclude these local functions from originizing
           functions <-
             exclude_functions(
@@ -126,6 +126,6 @@ exclude_local_functions <- function(functions,
     }
   }
   # nocov end
-
+  
   return(functions)
 }
