@@ -134,9 +134,7 @@ originize_pkg <-
     scripts <- suppressWarnings(lapply(files, readLines))
     
     # check for empty scripts
-    empty_scripts <- vapply(X = scripts,
-                            FUN = length,
-                            FUN.VALUE = integer(1)) == 0
+    empty_scripts <- lengths(x = scripts) == 0
     
     if (all(empty_scripts)) {
       message("All provided scripts are empty")
